@@ -796,6 +796,11 @@ urlpatterns = [
                                                         pages.restore_page,
                                                         name="restore_page",
                                                     ),
+                                                    path(
+                                                        "refresh/",
+                                                        pages.refresh_date,
+                                                        name="refresh_page",
+                                                    ),
                                                     path(
                                                         "delete/",
                                                         pages.delete_page,
@@ -930,9 +935,9 @@ urlpatterns = [
                                                         name="edit_event",
                                                     ),
                                                     path(
-                                                        "duplicate/",
-                                                        events.duplicate,
-                                                        name="duplicate_event",
+                                                        "copy/",
+                                                        events.copy,
+                                                        name="copy_event",
                                                     ),
                                                     path(
                                                         "archive/",
